# artypy - lightweight library for artistic filters

## Installation
```bash
pip install artypy
```

If you want to use cuda for nn module, you should install pytorch with cuda, or simply:
```bash
pip install artypy[cuda]
```

You can see usage examples in the _demo folder of the github repository:

https://github.com/artypy/arty